@@ -1,10 +1,10 @@
-#!/usr/bin/perl -w
+#!/mit/belg4mit/arch/sun4x_59/bin/perl -w
 use constant PRIVb => 0xF0000;
 use constant PRIVe => 0xFFFFD;
 use strict;
 use vars '$VERSION';
 use Text::FIGlet 2.01;
-$VERSION = 2.19.1;
+$VERSION = 2.1.2_2;
 
 my %opts;
 $opts{$_} = undef for
@@ -70,8 +70,7 @@ my @buffer;
 			    -D=>1,
 			    -d=>$opts{d},
 			    -m=>'-0',
-			    -f=>$opts{f},
-			    -U=>1);
+			    -f=>$opts{f});
 
 #XXX  $n = int($opts{w}||80 / $font->{_maxLen});
 
@@ -226,7 +225,7 @@ to  the  given integer.   An  outputwidth  of 1 is a
 special value that tells FIGlet to print each non-
 space  character, in its entirety, on a separate line,
 no matter how wide it is. Another special outputwidth
-is -1, it means to not wrap.
+is -1, it means to not warp.
 
 =back
 
@@ -260,12 +259,6 @@ FIGlet font files, these can be found at
  ftp://wuarchive.wustl.edu/graphics/graphics/misc/figlet/
  ftp://ftp.plig.org/pub/figlet/
 
-=head1 CAVEATS
-
-The L<Text::Wrap> in perl 5.6 or earlier operate on bytes,
-consequently the display of characters greater than 0x100
-end up wrapped across two rows.
-
 =head1 SEE ALSO
 
 L<figlet>, L<Text::FIGlet>
