@@ -1,18 +1,18 @@
-#!/usr/bin/perl -w
+#!/mit/belg4mit/arch/sun4x_59/bin/perl -w
 package main;
 use strict;
 use vars '$VERSION';
 use Text::FIGlet 2.01;
-$VERSION = 2.19.2;
+$VERSION = 2.1.2; #2.02
 
 my %opts;
 $opts{-C} = [];
 $opts{$_} = undef for
-  qw(A D E L R U X c d e f h help -help l r x);
+  qw(A D E L R U X c e h help -help l r x);
 $opts{$_} = "0 but true" for
-  qw(I m w);
+  qw(I d f m w);
 for (my $i=0; $i <= scalar @ARGV; $i++) {
-  last unless defined($ARGV[$i]);
+  last unless exists($ARGV[$i]);
   shift && last if $ARGV[$i] eq '--';
   if( $ARGV[$i]  =~ /^-N$/ ) {
     shift; $i--;
@@ -51,7 +51,7 @@ if( $opts{I} == 1 ){
 
 my $font = Text::FIGlet->new(-D=>$opts{D}&&!$opts{E},
 			  -d=>$opts{d},
-			  -m=>$opts{m}||-2,
+			  -m=>$opts{m},
 			  -f=>$opts{f});
 @_ = map { -C=> $_ } @{$opts{-C}} if scalar @{$opts{-C}};
 my $ctrl = Text::FIGlet->new( @_,
@@ -78,7 +78,6 @@ if( $opts{e} ){
 }
 if( $opts{A} ){
     $_ = join(' ', map($_ = $_ eq '' ? $/ : $_, @ARGV));
-    #XXXtraneous space...
     print scalar $font->figify(-A=>($ctrl ? $ctrl->tr() : $_), %figify);
     exit 0;
 }
@@ -144,15 +143,17 @@ files will be stored in FIGlet's default font directory.
 
 =item B<-A>
 
-All Words. Once the - arguments are read, all words remaining on the command
-line are used instead of standard input to print letters. Allows shell scripts
-to generate large letters without having to dummy up standard input files.
+All Words. Once the - arguments are read, all
+words remaining on the command line are used
+instead of standard input to print letters. Allows
+shell scripts to generate large letters without
+having to dummy up standard input files.
 
-An empty character, obtained by two sequential and empty quotes, results in a
-line break.
+An empty character, obtained by two sequential and
+empty quotes, results in a line break.
 
-To include text begining with - that might otherwise appear to be an invalid
-argument, use the argument --
+To include text begining with - that might otherwise
+appear to be an invalid argument, use the argument --
 
 =item B<-C>=F<controlfile>
 B<-N>
@@ -172,10 +173,11 @@ B<-E>
 
 B<-E> is the default, and a no-op.
 
-B<-D> switches  to  the German (ISO 646-DE) character set.
-Turns `[', `\' and `]' into umlauted A, O and U,  respectively.
-`{',  `|' and `}' turn into the respective lower case versions of these.
-`~' turns into  s-z.
+B<-D>  switches  to  the German (ISO 646-DE) character
+set.  Turns `[', `\' and `]' into umlauted A, O and
+U,  respectively.   `{',  `|' and `}' turn into the
+respective lower case versions of these.  `~' turns
+into  s-z.
 
 These options are deprecated, which means they may soon
 be removed. The modern way to achieve this effect is with
@@ -200,12 +202,13 @@ higher numbers.
 
 =item 2 Default font directory.
 
-This will print the default font directory. It is affected by the B<-d> option.
+This will print the default font directory. It is affected by the -d option.
 
 =item 3 Font.
 
-This will print the name of the font FIGlet would use. It is affected by the
-B<-f> option. This is not a filename; the I<.flf> suffix is not printed.
+This will print the name of the font FIGlet would use.
+It is affected by the B<-f> option. This is not a filename;
+the I<.flf> suffix is not printed.
 
 =back
 
@@ -213,9 +216,11 @@ B<-f> option. This is not a filename; the I<.flf> suffix is not printed.
 B<-R>
 B<-X>
 
-These options control whether FIGlet prints left-to-right or right-to-left.
-B<-L> selects left-to-right printing. B<-R> selects right-to-left printing.
-B<-X> (default) makes FIGlet use whichever is specified in the font file.
+These options control whether FIGlet prints
+left-to-right or right-to-left. B<-L> selects
+left-to-right printing. B<-R> selects right-to-left printing.
+B<-X> (default) makes FIGlet use whichever is specified
+in the font file.
 
 =item B<-U>
 
@@ -228,19 +233,24 @@ B<-l>
 B<-r>
 B<-x>
 
-These options handle the justification of FIGlet output. B<-c> centers the
-output horizontally. B<-l> makes the output flush-left. B<-r> makes it
-flush-right. B<-x> (default) sets the justification according to whether
-left-to-right or right-to-left text is selected. Left-to-right text will be
-flush-left, while right-to-left text will be flush-right. (Left-to-rigt
-versus right-to-left text is controlled by B<-L>, B<-R> and B<-X>.)
+These options handle the justification of FIGlet
+output. B<-c> centers the output horizontally. B<-l>
+makes the output flush-left. B<-r> makes it flush-right.
+B<-x> (default) sets the justification according
+to whether left-to-right or right-to-left text
+is selected. Left-to-right text will be flush-left,
+while right-to-left text will be flush-right.
+(Left-to-rigt versus right-to-left text is controlled by B<-L>,
+B<-R> and B<-X>.)
 
 =item B<-d>=F<fontdirectory>
 
-Change the default font directory. FIGlet looks for fonts first in the default
-directory and then in the current directory. If the B<-d> option is not
-specified, FIGlet uses the directory that was specified when it was compiled.
-To find out which directory this is, use the B<-I2> option.
+Change the default font directory. FIGlet looks
+for fonts first in the default directory and then
+in the current directory. If the B<-d> option is not
+specified, FIGlet uses the directory that was specified
+when it was compiled. To find out which
+directory this is, use the B<-I2> option.
 
 =item B<-e> C<EXPR>
 
@@ -249,22 +259,27 @@ This can be especially useful for retrieving Unicode characters.
 
 =item B<-f>=F<fontfile>
 
-Select the font. The I<.flf> suffix may be left off of fontfile, in which case
-FIGlet automatically appends it. FIGlet looks for the file first in the default
-font directory and then in the current directory, or, if fontfile was given as
-a full pathname, in the given directory. If the B<-f> option is not specified,
-FIGlet uses the font that was specified when it was compiled. To find out which
+Select the font. The I<.flf> suffix may be left off
+of fontfile, in which case FIGlet automatically
+appends it. FIGlet looks for the file first in the
+default font directory and then in the current
+directory, or, if fontfile was given as a full
+pathname, in the given directory. If the B<-f> option
+is not specified, FIGlet uses the font that was
+specified when it was compiled. To find out which
 font this is, use the B<-I3> option.
 
-=item B<-m=>I<smushmode>
+=item B<-m=E<gt>>I<smushmode>
 
 Specifies how B<Text::FIGlet::Font> should ``smush'' and kern consecutive
-characters together. On the command line, B<-m0> can be useful, as it tells
-FIGlet to kern characters without smushing them together. Otherwise, this
-option is rarely needed, as a B<Text::FIGlet::Font> font file specifies the
-best smushmode to use with the font. B<-m> is, therefore, most useful to font
-designers testing the various smushmodes with their font. I<smushmode> can be
--2 through 63.
+characters together. On the command line,
+B<-m0> can be useful, as it tells FIGlet to kern characters
+without smushing them together. Otherwise,
+this option is rarely needed, as a B<Text::FIGlet::Font> font file
+specifies the best smushmode to use with the font.
+B<-m> is, therefore, most useful to font designers
+testing the various smushmodes with their font.
+smushmode can be -2 through 63.
 
 =over
 
